@@ -5,7 +5,7 @@ from nornir.core.task import Result, Task
 from nornir_f5.plugins.connections import f5_rest_client
 
 
-def f5_bigip_cm_failover_status(task: Task) -> Result:
+def bigip_cm_failover_status(task: Task) -> Result:
     """Task to get the failover status of the device.
 
     Args:
